@@ -40,7 +40,7 @@ def __configure_fastapi(tracer_provider, fastapi_app=None):
     @fastapi_app.middleware("http")
     async def add_trace_id_header(request, call_next):
         #request:Request
-        trace_id_req = request.eaders.get(__TRACE_ID_HEADER_NAME, None)
+        trace_id_req = request.headers.get(__TRACE_ID_HEADER_NAME, None)
         span_id_req = request.headers.get(__SPAN_ID_HEADER_NAME, None)
         span = start_span(request.url, trace_id_req, span_id_req)
         with span:
